@@ -8,7 +8,7 @@ pub use std::{
 };
 
 pub use anyhow::{anyhow, Context as _};
-use chrono::{Datelike, Local, TimeZone, Timelike, Utc};
+use chrono::Utc;
 pub use crusty_core::flume::{bounded as bounded_ch, unbounded as unbounded_ch, Receiver, RecvError, Sender};
 pub use tokio::time::{self, timeout, Duration, Instant};
 pub use tracing::{debug, error, info, trace, warn, Level};
@@ -16,7 +16,5 @@ pub use tracing_tools::{span, PinnedFut, TracingTask};
 pub use url::Url;
 
 pub fn now() -> u32 {
-	let dt = Local::now();
-	let u = Utc.ymd(dt.year(), dt.month(), dt.day()).and_hms_nano(dt.hour(), dt.minute(), dt.second(), dt.nanosecond());
-	u.timestamp() as u32
+	Utc::now().timestamp() as u32
 }
